/// <reference types="node" />
/// <reference types="node" />
import crypto from 'crypto';
import { ASN1Obj } from './asn1/obj';
import { x509BasicConstraintsExtension, x509KeyUsageExtension, x509SCTExtension } from './ext';
export declare class x509Certificate {
    root: ASN1Obj;
    constructor(asn1: ASN1Obj);
    static fromDER(der: Buffer): x509Certificate;
    get tbsCertificate(): Buffer;
    get version(): string;
    get notBefore(): Date;
    get notAfter(): Date;
    get issuer(): Buffer;
    get subject(): Buffer;
    get publicKey(): crypto.KeyObject;
    get signatureAlgorithm(): string;
    get signatureValue(): Buffer;
    get extKeyUsage(): x509KeyUsageExtension | undefined;
    get extBasicConstraints(): x509BasicConstraintsExtension | undefined;
    get extSCT(): x509SCTExtension | undefined;
    private findExtension;
    private get tbsCertificateObj();
    private get signatureAlgorithmObj();
    private get signatureValueObj();
    private get versionObj();
    private get issuerObj();
    private get validityObj();
    private get subjectObj();
    private get subjectPublicKeyInfoObj();
    private get extensionsObj();
}
